==> libwmf-0.2.8.4-i586-8.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf libwmf.so )
( cd usr/lib ; ln -sf libwmf-0.2.so.7.1.0 libwmf.so )
( cd usr/lib ; rm -rf libwmflite-0.2.so.7 )
( cd usr/lib ; ln -sf libwmflite-0.2.so.7.0.1 libwmflite-0.2.so.7 )
( cd usr/lib ; rm -rf libwmf-0.2.so.7 )
( cd usr/lib ; ln -sf libwmf-0.2.so.7.1.0 libwmf-0.2.so.7 )
( cd usr/lib ; rm -rf libwmflite.so )
( cd usr/lib ; ln -sf libwmflite-0.2.so.7.0.1 libwmflite.so )
( cd usr/share/libwmf/fonts ; rm -rf n022004l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n022004l.afm n022004l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n021023l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n021023l.pfb n021023l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf s050000l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/s050000l.afm s050000l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n022023l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n022023l.pfb n022023l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf n022024l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n022024l.afm n022024l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n021003l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n021003l.afm n021003l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n021004l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n021004l.pfb n021004l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf n019023l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n019023l.afm n019023l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n019003l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n019003l.pfb n019003l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf n021003l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n021003l.pfb n021003l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf n021024l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n021024l.pfb n021024l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf n022003l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n022003l.afm n022003l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n021023l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n021023l.afm n021023l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n022003l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n022003l.pfb n022003l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf n022023l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n022023l.afm n022023l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n021024l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n021024l.afm n021024l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n019004l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n019004l.pfb n019004l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf n019004l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n019004l.afm n019004l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n021004l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n021004l.afm n021004l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n019023l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n019023l.pfb n019023l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf n019024l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n019024l.pfb n019024l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf n022004l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n022004l.pfb n022004l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf s050000l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/s050000l.pfb s050000l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf n022024l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n022024l.pfb n022024l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf n019024l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n019024l.afm n019024l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n019003l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n019003l.afm n019003l.afm )

==> libwmf-0.2.12-i586-3.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf libwmf-0.2.so.7 )
( cd usr/lib ; ln -sf libwmf-0.2.so.7.1.4 libwmf-0.2.so.7 )
( cd usr/lib ; rm -rf libwmf.so )
( cd usr/lib ; ln -sf libwmf-0.2.so.7.1.4 libwmf.so )
( cd usr/lib ; rm -rf libwmflite-0.2.so.7 )
( cd usr/lib ; ln -sf libwmflite-0.2.so.7.0.5 libwmflite-0.2.so.7 )
( cd usr/lib ; rm -rf libwmflite.so )
( cd usr/lib ; ln -sf libwmflite-0.2.so.7.0.5 libwmflite.so )
( cd usr/share/libwmf/fonts ; rm -rf n019003l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n019003l.afm n019003l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n019003l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n019003l.pfb n019003l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf n019004l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n019004l.afm n019004l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n019004l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n019004l.pfb n019004l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf n019023l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n019023l.afm n019023l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n019023l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n019023l.pfb n019023l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf n019024l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n019024l.afm n019024l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n019024l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n019024l.pfb n019024l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf n021003l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n021003l.afm n021003l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n021003l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n021003l.pfb n021003l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf n021004l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n021004l.afm n021004l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n021004l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n021004l.pfb n021004l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf n021023l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n021023l.afm n021023l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n021023l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n021023l.pfb n021023l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf n021024l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n021024l.afm n021024l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n021024l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n021024l.pfb n021024l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf n022003l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n022003l.afm n022003l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n022003l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n022003l.pfb n022003l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf n022004l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n022004l.afm n022004l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n022004l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n022004l.pfb n022004l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf n022023l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n022023l.afm n022023l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n022023l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n022023l.pfb n022023l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf n022024l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n022024l.afm n022024l.afm )
( cd usr/share/libwmf/fonts ; rm -rf n022024l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/n022024l.pfb n022024l.pfb )
( cd usr/share/libwmf/fonts ; rm -rf s050000l.afm )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/s050000l.afm s050000l.afm )
( cd usr/share/libwmf/fonts ; rm -rf s050000l.pfb )
( cd usr/share/libwmf/fonts ; ln -sf ../../fonts/Type1/s050000l.pfb s050000l.pfb )
